==> coos.app-2.2.3.5-sources.jar: top/coos/app/entity/Entity.java <==
package top.coos.app.entity;

public abstract class Entity {

	private String id;

	private String createtime;

	private String lastupdatetime;

	private String description;

	private String accountcode;

	private String accountname;

	private String lastupdateaccountcode;

	private String lastupdateaccountname;

	public String getAccountname() {

		return accountname;
	}

	public void setAccountname(String accountname) {

		this.accountname = accountname;
	}

	public String getLastupdateaccountname() {

		return lastupdateaccountname;
	}

	public void setLastupdateaccountname(String lastupdateaccountname) {

		this.lastupdateaccountname = lastupdateaccountname;
	}

	public String getLastupdateaccountcode() {

		return lastupdateaccountcode;
	}

	public void setLastupdateaccountcode(String lastupdateaccountcode) {

		this.lastupdateaccountcode = lastupdateaccountcode;
	}

	public String getAccountcode() {

		return accountcode;
	}

	public void setAccountcode(String accountcode) {

		this.accountcode = accountcode;
	}

	public String getId() {

		return id;
	}

	public void setId(String id) {

		this.id = id;
	}

	public String getDescription() {

		return description;
	}

	public void setDescription(String description) {

		this.description = description;
	}

	public String getLastupdatetime() {

		return lastupdatetime;
	}

	public void setLastupdatetime(String lastupdatetime) {

		this.lastupdatetime = lastupdatetime;
	}

	public String getCreatetime() {

		return createtime;
	}

	public void setCreatetime(String createtime) {

		this.createtime = createtime;
	}

}

==> coos.app-2.2.6.9-sources.jar: top/coos/app/entity/Entity.java <==
package top.coos.app.entity;

public abstract class Entity {

	private String id;

	private String createtime;

	private String lastupdatetime;

	private String description;

	private String accountcode;

	private String accountname;

	private int sequence;

	private String lastupdateaccountcode;

	private String lastupdateaccountname;

	public int getSequence() {

		return sequence;
	}

	public void setSequence(int sequence) {

		this.sequence = sequence;
	}

	public String getAccountname() {

		return accountname;
	}

	public void setAccountname(String accountname) {

		this.accountname = accountname;
	}

	public String getLastupdateaccountname() {

		return lastupdateaccountname;
	}

	public void setLastupdateaccountname(String lastupdateaccountname) {

		this.lastupdateaccountname = lastupdateaccountname;
	}

	public String getLastupdateaccountcode() {

		return lastupdateaccountcode;
	}

	public void setLastupdateaccountcode(String lastupdateaccountcode) {

		this.lastupdateaccountcode = lastupdateaccountcode;
	}

	public String getAccountcode() {

		return accountcode;
	}

	public void setAccountcode(String accountcode) {

		this.accountcode = accountcode;
	}

	public String getId() {

		return id;
	}

	public void setId(String id) {

		this.id = id;
	}

	public String getDescription() {

		return description;
	}

	public void setDescription(String description) {

		this.description = description;
	}

	public String getLastupdatetime() {

		return lastupdatetime;
	}

	public void setLastupdatetime(String lastupdatetime) {

		this.lastupdatetime = lastupdatetime;
	}

	public String getCreatetime() {

		return createtime;
	}

	public void setCreatetime(String createtime) {

		this.createtime = createtime;
	}

}
